@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,19 +19,20 @@ import static org.junit.Assert.*;
 
 import java.io.File;
 import java.io.IOException;
-import java.util.*;
+import java.util.Collection;
+import java.util.Set;
 
 import org.junit.*;
 
 import db.Transaction;
-import ghidra.program.model.address.Address;
-import ghidra.program.model.address.AddressSpace;
+import ghidra.program.model.address.*;
 import ghidra.program.model.symbol.*;
 import ghidra.test.AbstractGhidraHeadlessIntegrationTest;
 import ghidra.trace.database.ToyDBTraceBuilder;
 import ghidra.trace.model.Lifespan;
 import ghidra.trace.model.Trace;
 import ghidra.trace.model.symbol.*;
+import ghidra.trace.util.TraceRegisterUtils;
 import ghidra.util.exception.CancelledException;
 import ghidra.util.exception.VersionException;
 
@@ -39,12 +40,12 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 	protected static class DummyTraceReference implements TraceReference {
 		protected final Lifespan lifespan;
 		protected final Address fromAddress;
-		protected final Address toAddress;
+		protected final AddressRange toRange;
 
-		public DummyTraceReference(long startSnap, Address fromAddress, Address toAddress) {
+		public DummyTraceReference(long startSnap, Address fromAddress, AddressRange toRange) {
 			this.lifespan = Lifespan.nowOn(startSnap);
 			this.fromAddress = fromAddress;
-			this.toAddress = toAddress;
+			this.toRange = toRange;
 		}
 
 		@Override
@@ -53,8 +54,8 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		}
 
 		@Override
-		public Address getToAddress() {
-			return toAddress;
+		public AddressRange getToRange() {
+			return toRange;
 		}
 
 		@Override
@@ -130,7 +131,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 
 		public DummyTraceOffsetReference(long startSnap, Address fromAddress, Address toAddress,
 				long offset) {
-			super(startSnap, fromAddress, toAddress);
+			super(startSnap, fromAddress, new AddressRangeImpl(toAddress, toAddress));
 			this.offset = offset;
 			// NOTE: intended for test use in the absence of any EXTERNAL memory block concern
 			this.baseAddress = toAddress.subtract(offset);
@@ -154,7 +155,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 
 		public DummyTraceShiftedReference(long startSnap, Address fromAddress, Address toAddress,
 				int shift) {
-			super(startSnap, fromAddress, toAddress);
+			super(startSnap, fromAddress, new AddressRangeImpl(toAddress, toAddress));
 			this.shift = shift;
 			this.value = toAddress.getOffset() >>> shift;
 		}
@@ -190,8 +191,8 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference offRef;
 		DBTraceReference sftRef;
 		try (Transaction tx = b.startTransaction()) {
-			memRef =
-				manager.addReference(new DummyTraceReference(0, b.addr(0x4000), b.addr(0x5000)));
+			memRef = manager.addReference(
+				new DummyTraceReference(0, b.addr(0x4000), b.range(0x5000, 0x5003)));
 			offRef = manager.addReference(
 				new DummyTraceOffsetReference(0, b.addr(0x4001), b.addr(0x5001), 20));
 			sftRef = manager.addReference(
@@ -203,6 +204,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		assertTrue(sftRef instanceof DBTraceShiftedReference);
 
 		assertEquals(b.addr(0x4000), memRef.getFromAddress());
+		assertEquals(b.range(0x5000, 0x5003), memRef.getToRange());
 		assertEquals(b.addr(0x5000), memRef.getToAddress());
 
 		assertEquals(b.addr(0x4001), offRef.getFromAddress());
@@ -219,7 +221,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 	@Test
 	public void testAddMemoryReference() {
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 		}
 		DBTraceReferenceSpace space =
 			manager.getReferenceSpace(b.language.getDefaultDataSpace(), false);
@@ -284,7 +286,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference regRef;
 		DBTraceReference stkRef;
 		try (Transaction tx = b.startTransaction()) {
-			memRef = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			memRef = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			offRef = b.addOffsetReference(0, b.addr(0x4001), b.addr(0x5001), false, 20);
 			sftRef = b.addShiftedReference(0, b.addr(0x4002), b.addr(0x5002), 1);
 			regRef = b.addRegisterReference(0, b.addr(0x4003), "r5");
@@ -292,20 +294,21 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		}
 
 		assertNull(manager.getReference(0, b.addr(0x4000), b.addr(0x5000), 0));
+		assertNull(manager.getReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 0));
 		assertNull(manager.getReference(0, b.addr(0x4000), b.addr(0x5001), -1));
 		assertNull(manager.getReference(0, b.addr(0x4001), b.addr(0x5000), -1));
 		assertNull(manager.getReference(-1, b.addr(0x4000), b.addr(0x5000), -1));
-		assertEquals(memRef, manager.getReference(0, b.addr(0x4000), b.addr(0x5000), -1));
-		assertEquals(memRef, manager.getReference(10, b.addr(0x4000), b.addr(0x5000), -1));
+		assertEquals(memRef, manager.getReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), -1));
+		assertEquals(memRef, manager.getReference(10, b.addr(0x4000), b.range(0x5000, 0x5003), -1));
 
 		assertEquals(offRef, manager.getReference(0, b.addr(0x4001), b.addr(0x5001), -1));
 
 		assertEquals(sftRef, manager.getReference(0, b.addr(0x4002), b.addr(0x5002), -1));
 
-		assertEquals(regRef,
-			manager.getReference(0, b.addr(0x4003), b.language.getRegister("r5").getAddress(), -1));
-		assertNull(
-			manager.getReference(0, b.addr(0x4003), b.language.getRegister("r6").getAddress(), -1));
+		assertEquals(regRef, manager.getReference(0, b.addr(0x4003),
+			TraceRegisterUtils.rangeForRegister(b.language.getRegister("r5")), -1));
+		assertNull(manager.getReference(0, b.addr(0x4003),
+			TraceRegisterUtils.rangeForRegister(b.language.getRegister("r6")), -1));
 
 		// TODO: A better way to manage the compiler spec
 		assertEquals(stkRef, manager.getReference(0, b.addr(0x4004),
@@ -322,21 +325,21 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference regRef;
 		DBTraceReference stkRef;
 		try (Transaction tx = b.startTransaction()) {
-			memRef = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000), 3);
+			memRef = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 3);
 			offRef = b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 			sftRef = b.addShiftedReference(0, b.addr(0x4000), b.addr(0x5002), 1);
 			regRef = b.addRegisterReference(0, b.addr(0x4000), "r5");
 			stkRef = b.addStackReference(0, b.addr(0x4000), 0x20);
 
-			b.addMemoryReference(0, b.addr(0x4001), b.addr(0x8000));
+			b.addMemoryReference(0, b.addr(0x4001), b.range(0x8000, 0x8003));
 		}
 
 		assertEquals(Set.of(memRef, offRef, sftRef, regRef, stkRef),
-			new HashSet<>(manager.getReferencesFrom(0, b.addr(0x4000))));
+			Set.copyOf(manager.getReferencesFrom(0, b.addr(0x4000))));
 		assertEquals(Set.of(memRef),
-			new HashSet<>(manager.getReferencesFrom(0, b.addr(0x4000), 3)));
+			Set.copyOf(manager.getReferencesFrom(0, b.addr(0x4000), 3)));
 		assertEquals(Set.of(offRef, sftRef, regRef, stkRef),
-			new HashSet<>(manager.getReferencesFrom(0, b.addr(0x4000), -1)));
+			Set.copyOf(manager.getReferencesFrom(0, b.addr(0x4000), -1)));
 	}
 
 	@Test
@@ -347,23 +350,23 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference diffTo;
 		DBTraceReference diffOpIndex;
 		try (Transaction tx = b.startTransaction()) {
-			at0 = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000), 0);
-			b.addMemoryReference(15, b.addr(0x4000), b.addr(0x5000), 0); // Lost
-			at10 = b.addMemoryReference(10, b.addr(0x4000), b.addr(0x5000), 0);
+			at0 = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 0);
+			b.addMemoryReference(15, b.addr(0x4000), b.range(0x5000, 0x5003), 0); // Lost
+			at10 = b.addMemoryReference(10, b.addr(0x4000), b.range(0x5000, 0x5003), 0);
 
-			diffFrom = b.addMemoryReference(0, b.addr(0x4001), b.addr(0x5000), 0);
-			diffTo = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5001), 0);
-			diffOpIndex = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000), 1);
+			diffFrom = b.addMemoryReference(0, b.addr(0x4001), b.range(0x5000, 0x5003), 0);
+			diffTo = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5004, 0x5007), 0);
+			diffOpIndex = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 1);
 
 			assertEquals(Set.of(at0, diffTo, diffOpIndex),
-				new HashSet<>(manager.getReferencesFrom(0, b.addr(0x4000))));
+				Set.copyOf(manager.getReferencesFrom(0, b.addr(0x4000))));
 			assertEquals(Set.of(at10, diffTo, diffOpIndex),
-				new HashSet<>(manager.getReferencesFrom(15, b.addr(0x4000))));
+				Set.copyOf(manager.getReferencesFrom(15, b.addr(0x4000))));
 
 			assertEquals(Set.of(diffFrom),
-				new HashSet<>(manager.getReferencesFrom(0, b.addr(0x4001))));
+				Set.copyOf(manager.getReferencesFrom(0, b.addr(0x4001))));
 			assertEquals(Set.of(diffFrom),
-				new HashSet<>(manager.getReferencesFrom(15, b.addr(0x4001))));
+				Set.copyOf(manager.getReferencesFrom(15, b.addr(0x4001))));
 		}
 	}
 
@@ -375,7 +378,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference memRef;
 		DBTraceReference offRef;
 		try (Transaction tx = b.startTransaction()) {
-			memRef = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			memRef = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			offRef = b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 
 			assertNull(manager.getPrimaryReferenceFrom(0, b.addr(0x4000), -1));
@@ -395,28 +398,28 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 
 	@Test
 	public void testGetFlowReferencesFrom() {
-		DBTraceReference flowRef;
+		TraceReference flowRef;
 		try (Transaction tx = b.startTransaction()) {
 			flowRef = manager.addMemoryReference(Lifespan.nowOn(0), b.addr(0x4000), b.addr(0x4001),
 				RefType.FLOW, SourceType.DEFAULT, -1);
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 		}
 
 		assertEquals(Set.of(flowRef),
-			new HashSet<>(manager.getFlowReferencesFrom(0, b.addr(0x4000))));
+			Set.copyOf(manager.getFlowReferencesFrom(0, b.addr(0x4000))));
 	}
 
 	@Test
 	public void testClearReferencesFrom() {
 		DBTraceReference keptRef;
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000), 3);
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 3);
 			b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 			b.addShiftedReference(0, b.addr(0x4000), b.addr(0x5002), 1);
 			b.addRegisterReference(0, b.addr(0x4000), "r5");
 			b.addStackReference(0, b.addr(0x4000), 0x20);
-			keptRef = b.addMemoryReference(0, b.addr(0x4001), b.addr(0x8000));
+			keptRef = b.addMemoryReference(0, b.addr(0x4001), b.range(0x8000, 0x8003));
 		}
 
 		assertEquals(5, manager.getReferencesFrom(0, b.addr(0x4000)).size());
@@ -448,27 +451,46 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		DBTraceReference offRef;
 		DBTraceReference sftRef;
 		try (Transaction tx = b.startTransaction()) {
-			memRef = b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			memRef = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			offRef = b.addOffsetReference(0, b.addr(0x4001), b.addr(0x5000), false, 20);
 			sftRef = b.addShiftedReference(0, b.addr(0x4002), b.addr(0x5000), 1);
 			b.addRegisterReference(0, b.addr(0x4003), "r5");
 			b.addStackReference(0, b.addr(0x4004), 0x20);
 
-			b.addMemoryReference(0, b.addr(0x4005), b.addr(0x8000));
+			b.addMemoryReference(0, b.addr(0x4005), b.range(0x8000, 0x8003));
 		}
 
 		assertEquals(Set.of(memRef, offRef, sftRef),
-			new HashSet<>(manager.getReferencesTo(0, b.addr(0x5000))));
+			Set.copyOf(manager.getReferencesTo(0, b.addr(0x5000))));
+	}
+
+	@Test
+	public void tesGetReferencesToRange() {
+		DBTraceReference memRef1;
+		DBTraceReference memRef2;
+		DBTraceReference memRef3;
+		try (Transaction tx = b.startTransaction()) {
+			memRef1 = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
+			memRef2 = b.addMemoryReference(5, b.addr(0x4000), b.range(0x5002, 0x5005));
+			memRef3 = b.addMemoryReference(0, b.addr(0x4000), b.range(0x5004, 0x5007));
+		}
+
+		assertEquals(Set.of(memRef1, memRef2, memRef3),
+			Set.copyOf(manager.getReferencesToRange(Lifespan.nowOn(0), b.range(0x5000, 0x5007))));
+		assertEquals(Set.of(memRef1),
+			Set.copyOf(manager.getReferencesToRange(Lifespan.nowOn(0), b.range(0x5000, 0x5000))));
+		assertEquals(Set.of(memRef1, memRef3),
+			Set.copyOf(manager.getReferencesToRange(Lifespan.at(0), b.range(0x5000, 0x5007))));
 	}
 
 	@Test
 	public void testClearReferencesTo() {
 		DBTraceReference keptRef;
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000), 3);
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), 3);
 			b.addOffsetReference(0, b.addr(0x4001), b.addr(0x5000), false, 20);
 			b.addShiftedReference(0, b.addr(0x4002), b.addr(0x5000), 1);
-			keptRef = b.addMemoryReference(0, b.addr(0x8000), b.addr(0x5001));
+			keptRef = b.addMemoryReference(0, b.addr(0x8000), b.range(0x5004, 0x5007));
 		}
 
 		assertEquals(3, manager.getReferencesTo(0, b.addr(0x5000)).size());
@@ -489,26 +511,26 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 
 		assertEquals(0, manager.getReferencesTo(0, b.addr(0x5000)).size());
 		assertEquals(0, manager.getReferencesTo(-1, b.addr(0x5000)).size());
-		assertEquals(1, manager.getReferencesTo(0, b.addr(0x5001)).size());
-		assertEquals(keptRef, manager.getReferencesTo(0, b.addr(0x5001)).iterator().next());
+		assertEquals(1, manager.getReferencesTo(0, b.addr(0x5004)).size());
+		assertEquals(keptRef, manager.getReferencesTo(0, b.addr(0x5004)).iterator().next());
 		assertEquals(Lifespan.nowOn(0), keptRef.getLifespan());
 	}
 
 	@Test
 	public void testGetReferenceSourcesAndDestinations() {
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5000));
 			b.addOffsetReference(0, b.addr(0x4001), b.addr(0x5001), false, 20);
 			b.addShiftedReference(0, b.addr(0x4002), b.addr(0x5002), 1);
 			b.addRegisterReference(0, b.addr(0x4003), "r5");
 			b.addStackReference(0, b.addr(0x4004), 0x20);
-			b.addMemoryReference(0, b.addr(0x4005), b.addr(0x8000));
+			b.addMemoryReference(0, b.addr(0x4005), b.range(0x8000, 0x8003));
 		}
 
 		assertEquals(b.set(b.range(0x4000, 0x4005)),
 			manager.getReferenceSources(Lifespan.span(0, 0)));
 		assertEquals(b.set(), manager.getReferenceSources(Lifespan.span(-1, -1)));
-		assertEquals(b.set(b.range(0x5000, 0x5002), b.range(0x8000, 0x8000)),
+		assertEquals(b.set(b.range(0x5000, 0x5002), b.range(0x8000, 0x8003)),
 			manager.getReferenceDestinations(Lifespan.span(0, 0)));
 		assertEquals(b.set(), manager.getReferenceDestinations(Lifespan.span(-1, -1)));
 	}
@@ -519,13 +541,13 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 		assertEquals(0, manager.getReferenceCountTo(0, b.addr(0x5000)));
 
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 			b.addShiftedReference(0, b.addr(0x4000), b.addr(0x5002), 1);
 			b.addRegisterReference(0, b.addr(0x4000), "r5");
 			b.addStackReference(0, b.addr(0x4000), 0x20);
-			b.addMemoryReference(0, b.addr(0x4001), b.addr(0x5000));
-			b.addMemoryReference(0, b.addr(0x4002), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4001), b.range(0x5000, 0x5003));
+			b.addMemoryReference(0, b.addr(0x4002), b.range(0x5000, 0x5003));
 		}
 
 		assertEquals(5, manager.getReferenceCountFrom(0, b.addr(0x4000)));
@@ -537,7 +559,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 	@Test
 	public void testSaveAndLoad() throws CancelledException, IOException, VersionException {
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 			b.addShiftedReference(0, b.addr(0x4000), b.addr(0x5002), 1);
 		}
@@ -553,9 +575,9 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 				manager.getReferencesFrom(0, b.addr(0x4000));
 			assertEquals(3, refs.size());
 
-			DBTraceReference ref;
+			TraceReference ref;
 
-			ref = manager.getReference(0, b.addr(0x4000), b.addr(0x5000), -1);
+			ref = manager.getReference(0, b.addr(0x4000), b.range(0x5000, 0x5003), -1);
 			assertEquals(DBTraceReference.class, ref.getClass());
 			assertEquals(RefType.DATA, ref.getReferenceType());
 			assertEquals(SourceType.DEFAULT, ref.getSource());
@@ -574,7 +596,7 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 	@Test
 	public void testUndo() throws IOException {
 		try (Transaction tx = b.startTransaction()) {
-			b.addMemoryReference(0, b.addr(0x4000), b.addr(0x5000));
+			b.addMemoryReference(0, b.addr(0x4000), b.range(0x5000, 0x5003));
 			b.addOffsetReference(0, b.addr(0x4000), b.addr(0x5001), false, 20);
 			b.addShiftedReference(0, b.addr(0x4000), b.addr(0x5002), 1);
 		}
@@ -597,9 +619,9 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 					.createOverlayAddressSpace("test",
 						b.trace.getBaseAddressFactory().getDefaultAddressSpace());
 
-			b.addMemoryReference(0, os.getAddress(0x4000), os.getAddress(0x5000));
-			b.addMemoryReference(0, os.getAddress(0x4001), b.addr(0x5001));
-			b.addMemoryReference(0, b.addr(0x4002), os.getAddress(0x5002));
+			b.addMemoryReference(0, os.getAddress(0x4000), b.range(os, 0x5000, 0x5003));
+			b.addMemoryReference(0, os.getAddress(0x4001), b.range(0x5004, 0x5007));
+			b.addMemoryReference(0, b.addr(0x4002), b.range(os, 0x5008, 0x500b));
 		}
 
 		File saved = b.save();
@@ -613,19 +635,19 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 			AddressSpace os = b.trace.getBaseAddressFactory().getAddressSpace("test");
 			assertNotNull(os);
 
-			DBTraceReference ref;
+			TraceReference ref;
 
-			ref = manager.getReference(0, os.getAddress(0x4000), os.getAddress(0x5000), -1);
+			ref = manager.getReference(0, os.getAddress(0x4000), b.range(os, 0x5000, 0x5003), -1);
 			assertNotNull(ref);
 			assertEquals(os, ref.getFromAddress().getAddressSpace());
 			assertEquals(os, ref.getToAddress().getAddressSpace());
 
-			ref = manager.getReference(0, os.getAddress(0x4001), b.addr(0x5001), -1);
+			ref = manager.getReference(0, os.getAddress(0x4001), b.range(0x5004, 0x5007), -1);
 			assertNotNull(ref);
 			assertEquals(os, ref.getFromAddress().getAddressSpace());
 			assertEquals(ds, ref.getToAddress().getAddressSpace());
 
-			ref = manager.getReference(0, b.addr(0x4002), os.getAddress(0x5002), -1);
+			ref = manager.getReference(0, b.addr(0x4002), b.range(os, 0x5008, 0x500b), -1);
 			assertNotNull(ref);
 			assertEquals(ds, ref.getFromAddress().getAddressSpace());
 			assertEquals(os, ref.getToAddress().getAddressSpace());
@@ -636,11 +658,11 @@ public class DBTraceReferenceManagerTest extends AbstractGhidraHeadlessIntegrati
 			assertEquals(0, manager.getReferenceCountFrom(0, os.getAddress(0x4002)));
 			assertEquals(1, manager.getReferenceCountFrom(0, b.addr(0x4002)));
 
-			assertEquals(0, manager.getReferenceCountTo(0, os.getAddress(0x5001)));
-			assertEquals(1, manager.getReferenceCountTo(0, b.addr(0x5001)));
+			assertEquals(0, manager.getReferenceCountTo(0, os.getAddress(0x5004)));
+			assertEquals(1, manager.getReferenceCountTo(0, b.addr(0x5004)));
 
-			assertEquals(0, manager.getReferenceCountTo(0, b.addr(0x5002)));
-			assertEquals(1, manager.getReferenceCountTo(0, os.getAddress(0x5002)));
+			assertEquals(0, manager.getReferenceCountTo(0, b.addr(0x5008)));
+			assertEquals(1, manager.getReferenceCountTo(0, os.getAddress(0x5008)));
 		}
 	}
 }
