@@ -42,7 +42,6 @@ import ghidra.program.model.listing.Program;
 import ghidra.program.util.ProgramLocation;
 import ghidra.test.AbstractGhidraHeadedIntegrationTest;
 import ghidra.test.TestEnv;
-import ghidra.util.task.TaskMonitor;
 import utilities.util.FileUtilities;
 
 public class GhidraScriptAskMethodsTest extends AbstractGhidraHeadedIntegrationTest {
@@ -146,7 +145,6 @@ public class GhidraScriptAskMethodsTest extends AbstractGhidraHeadedIntegrationT
 
 		DataTreeDialog dtd = waitForDialogComponent(DataTreeDialog.class);
 		JButton okButton = (JButton) getInstanceField("okButton", dtd);
-
 		runSwing(() -> okButton.doClick());
 
 		// this test will fail if we encountered an exception
@@ -761,6 +759,7 @@ public class GhidraScriptAskMethodsTest extends AbstractGhidraHeadedIntegrationT
 			JComboBox<String> comboField =
 				(JComboBox<String>) findComponentByName(askDialog, "JComboBox");
 			setComboBoxSelection(comboField, optionalValue);
+
 			waitForSwing();
 		}
 
@@ -793,6 +792,7 @@ public class GhidraScriptAskMethodsTest extends AbstractGhidraHeadedIntegrationT
 		if (optionalValue != null) {
 			String name = "JTextField";
 			JTextField textField = (JTextField) findComponentByName(askDialog, name);
+			textField.getAccessibleContext().setAccessibleName("Option");
 			setText(textField, optionalValue);
 			waitForSwing();
 		}
@@ -901,7 +901,7 @@ public class GhidraScriptAskMethodsTest extends AbstractGhidraHeadedIntegrationT
 				// test stub
 			}
 		};
-		script.set(state, TaskMonitor.DUMMY, null);
+		script.set(state, ScriptControls.NONE);
 
 		URL url = GhidraScriptTest.class.getResource("GhidraScriptAsk.properties");
 		assertNotNull("Test cannot run without properties file!", url);
