@@ -15,7 +15,7 @@
  */
 package ghidraclass.debugger.screenshot;
 
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 
 import java.awt.Rectangle;
 import java.awt.event.MouseEvent;
@@ -74,8 +74,7 @@ import ghidra.app.plugin.core.terminal.TerminalProvider;
 import ghidra.app.script.GhidraState;
 import ghidra.app.services.*;
 import ghidra.app.services.DebuggerEmulationService.EmulationResult;
-import ghidra.app.util.importer.AutoImporter;
-import ghidra.app.util.importer.MessageLog;
+import ghidra.app.util.importer.ProgramLoader;
 import ghidra.app.util.opinion.LoadResults;
 import ghidra.async.AsyncTestUtils;
 import ghidra.debug.api.modules.ModuleMapProposal;
@@ -100,9 +99,10 @@ import ghidra.program.util.GhidraProgramUtilities;
 import ghidra.program.util.ProgramSelection;
 import ghidra.pty.*;
 import ghidra.test.TestEnv;
-import ghidra.trace.model.breakpoint.*;
+import ghidra.trace.model.breakpoint.TraceBreakpointLocation;
 import ghidra.trace.model.guest.TracePlatform;
-import ghidra.trace.model.modules.*;
+import ghidra.trace.model.modules.TraceModule;
+import ghidra.trace.model.modules.TraceSection;
 import ghidra.trace.model.program.TraceProgramView;
 import ghidra.trace.model.time.schedule.*;
 import ghidra.util.InvalidNameException;
@@ -309,6 +309,7 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 	public void testGettingStarted_DisassemblyAfterLaunch() throws Throwable {
 		launchProgramInGdb();
 
+		Thread.sleep(7000);
 		captureToolWindow(1920, 1080);
 	}
 
@@ -321,16 +322,12 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 	}
 
 	protected void waitBreakSpecExists(String expression) {
+		long snap = flatDbg.getCurrentSnap();
 		waitForCondition(() -> flatDbg.getAllBreakpoints()
 				.stream()
 				.flatMap(lb -> lb.getTraceBreakpoints().stream())
-				.<TraceObjectBreakpointSpec> mapMulti((loc, down) -> {
-					if (loc instanceof TraceObjectBreakpointLocation oloc) {
-						down.accept(oloc.getSpecification());
-					}
-				})
 				.distinct()
-				.filter(l -> expression.equals(l.getExpression()))
+				.filter(l -> expression.equals(l.getSpecification().getExpression(snap)))
 				.count() == 1);
 	}
 
@@ -354,23 +351,19 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 		launchProgramInGdb();
 		placeBreakpointsSRandRand();
 
-		tool.setSize(1920, 1080);
+		runSwing(() -> tool.setSize(1920, 1080));
 		captureProvider(DebuggerBreakpointsProvider.class);
 	}
 
 	protected Address navigateToBreakpoint(String expression) {
-		TraceBreakpoint bp = flatDbg.getAllBreakpoints()
+		long snap = flatDbg.getCurrentSnap();
+		TraceBreakpointLocation bp = flatDbg.getAllBreakpoints()
 				.stream()
 				.flatMap(l -> l.getTraceBreakpoints().stream())
-				.<TraceObjectBreakpointLocation> mapMulti((loc, down) -> {
-					if (loc instanceof TraceObjectBreakpointLocation oloc) {
-						down.accept(oloc);
-					}
-				})
-				.filter(l -> expression.equals(l.getSpecification().getExpression()))
+				.filter(l -> expression.equals(l.getSpecification().getExpression(snap)))
 				.findAny()
 				.get();
-		Address dynAddr = bp.getMinAddress();
+		Address dynAddr = bp.getMinAddress(snap);
 		flatDbg.goToDynamic(dynAddr);
 		return dynAddr;
 	}
@@ -387,12 +380,15 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 	protected Program importModule(TraceModule module) throws Throwable {
 		Program prog = null;
-		try {
-			MessageLog log = new MessageLog();
-			LoadResults<Program> result = AutoImporter.importByUsingBestGuess(
-				new File(module.getName()), env.getProject(), "/", this, log, monitor);
-			result.save(env.getProject(), this, log, monitor);
-			prog = result.getPrimaryDomainObject();
+		long snap = flatDbg.getCurrentSnap();
+		try (LoadResults<Program> result = ProgramLoader.builder()
+					.source(new File(module.getName(snap)))
+					.project(env.getProject())
+					.monitor(monitor)
+				.load()) {
+
+			result.save(monitor);
+			prog = result.getPrimaryDomainObject(this);
 			GhidraProgramUtilities.markProgramNotToAskToAnalyze(prog);
 			programManager.openProgram(prog);
 		}
@@ -435,7 +431,8 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 		// This module might be symlinked, so module name and file name may not match.
 		DebuggerStaticMappingService mappings = tool.getService(DebuggerStaticMappingService.class);
-		ModuleMapProposal proposal = mappings.proposeModuleMap(modLibC, progLibC);
+		ModuleMapProposal proposal =
+			mappings.proposeModuleMap(modLibC, flatDbg.getCurrentSnap(), progLibC);
 		try (Transaction tx = modLibC.getTrace().openTransaction("Map")) {
 			mappings.addModuleMappings(proposal.computeMap().values(), monitor, true);
 		}
@@ -461,7 +458,8 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 		// This module might be symlinked, so module name and file name may not match.
 		DebuggerStaticMappingService mappings = tool.getService(DebuggerStaticMappingService.class);
-		ModuleMapProposal proposal = mappings.proposeModuleMap(modLibC, progLibC);
+		ModuleMapProposal proposal =
+			mappings.proposeModuleMap(modLibC, flatDbg.getCurrentSnap(), progLibC);
 		try (Transaction tx = modLibC.getTrace().openTransaction("Map")) {
 			mappings.addModuleMappings(proposal.computeMap().values(), monitor, true);
 		}
@@ -574,7 +572,8 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 		// This module might be symlinked, so module name and file name may not match.
 		DebuggerStaticMappingService mappings = tool.getService(DebuggerStaticMappingService.class);
-		ModuleMapProposal proposal = mappings.proposeModuleMap(modLibC, progLibC);
+		ModuleMapProposal proposal =
+			mappings.proposeModuleMap(modLibC, flatDbg.getCurrentSnap(), progLibC);
 		try (Transaction tx = modLibC.getTrace().openTransaction("Map")) {
 			mappings.addModuleMappings(proposal.computeMap().values(), monitor, true);
 		}
@@ -596,7 +595,8 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 		// This module might be symlinked, so module name and file name may not match.
 		DebuggerStaticMappingService mappings = tool.getService(DebuggerStaticMappingService.class);
-		ModuleMapProposal proposal = mappings.proposeModuleMap(modLibC, progLibC);
+		ModuleMapProposal proposal =
+			mappings.proposeModuleMap(modLibC, flatDbg.getCurrentSnap(), progLibC);
 		try (Transaction tx = modLibC.getTrace().openTransaction("Map")) {
 			mappings.addModuleMappings(proposal.computeMap().values(), monitor, true);
 		}
@@ -635,27 +635,27 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 					.getSnapshot(snapA, false)
 					.setDescription("Initial snapshot");
 		}
-		TraceObjectModule modTermmines =
-			(TraceObjectModule) Unique.assertOne(flatDbg.getCurrentTrace()
-					.getModuleManager()
-					.getModulesAt(snapA, pc));
+		TraceModule modTermmines = Unique.assertOne(flatDbg.getCurrentTrace()
+				.getModuleManager()
+				.getModulesAt(snapA, pc));
 
 		RemoteMethod refreshSections = result.connection().getMethods().get("refresh_sections");
 		refreshSections.invoke(Map.of("node", modTermmines.getObject()));
-		TraceSection secTermminesData = modTermmines.getSectionByName(".data");
-		flatDbg.readMemory(secTermminesData.getStart(),
-			(int) secTermminesData.getRange().getLength(), monitor);
+		TraceSection secTermminesData = modTermmines.getSectionByName(snapA, ".data");
+		flatDbg.readMemory(secTermminesData.getStart(snapA),
+			(int) secTermminesData.getRange(snapA).getLength(), monitor);
 
 		flatDbg.resume(); // rand.1
 		Thread.sleep(500);
-		flatDbg.readMemory(secTermminesData.getStart(),
-			(int) secTermminesData.getRange().getLength(), monitor);
+		flatDbg.readMemory(secTermminesData.getStart(snapA),
+			(int) secTermminesData.getRange(snapA).getLength(), monitor);
 
 		performAction("Compare",
 			PluginUtils.getPluginNameFromClass(DebuggerTraceViewDiffPlugin.class), false);
 		DebuggerTimeSelectionDialog timeDialog =
 			waitForDialogComponent(DebuggerTimeSelectionDialog.class);
 		timeDialog.setScheduleText(TraceSchedule.snap(snapA).toString());
+		timeDialog.getComponent().requestFocus();
 		captureDialog(timeDialog);
 	}
 
@@ -671,21 +671,21 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 					.getSnapshot(snapA, false)
 					.setDescription("Initial snapshot");
 		}
-		TraceObjectModule modTermmines =
-			(TraceObjectModule) Unique.assertOne(flatDbg.getCurrentTrace()
-					.getModuleManager()
-					.getModulesAt(snapA, pc));
+		TraceModule modTermmines = Unique.assertOne(flatDbg.getCurrentTrace()
+				.getModuleManager()
+				.getModulesAt(snapA, pc));
 
 		RemoteMethod refreshSections = result.connection().getMethods().get("refresh_sections");
 		refreshSections.invoke(Map.of("node", modTermmines.getObject()));
-		TraceSection secTermminesData = modTermmines.getSectionByName(".data");
-		flatDbg.readMemory(secTermminesData.getStart(),
-			(int) secTermminesData.getRange().getLength(), monitor);
+		TraceSection secTermminesData = modTermmines.getSectionByName(snapA, ".data");
+		flatDbg.readMemory(secTermminesData.getStart(snapA),
+			(int) secTermminesData.getRange(snapA).getLength(), monitor);
 
 		flatDbg.resume(); // rand.1
 		flatDbg.waitForBreak(1000, TimeUnit.MILLISECONDS);
-		flatDbg.readMemory(secTermminesData.getStart(),
-			(int) secTermminesData.getRange().getLength(), monitor);
+		// snapA suffices, since section shouldn't have moved
+		flatDbg.readMemory(secTermminesData.getStart(snapA),
+			(int) secTermminesData.getRange(snapA).getLength(), monitor);
 
 		performAction("Compare",
 			PluginUtils.getPluginNameFromClass(DebuggerTraceViewDiffPlugin.class), false);
@@ -705,10 +705,10 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 			}
 		});
 		waitForCondition(() -> actionNextDiff.isEnabled());
-		flatDbg.goToDynamic(secTermminesData.getStart());
+		flatDbg.goToDynamic(secTermminesData.getStart(snapA));
 		// Because auto-track is a little broken right now
 		Thread.sleep(500);
-		flatDbg.goToDynamic(secTermminesData.getStart());
+		flatDbg.goToDynamic(secTermminesData.getStart(snapA));
 
 		performAction(actionNextDiff);
 
@@ -743,7 +743,8 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 
 		// This module might be symlinked, so module name and file name may not match.
 		DebuggerStaticMappingService mappings = tool.getService(DebuggerStaticMappingService.class);
-		ModuleMapProposal proposal = mappings.proposeModuleMap(modLibC, progLibC);
+		ModuleMapProposal proposal =
+			mappings.proposeModuleMap(modLibC, flatDbg.getCurrentSnap(), progLibC);
 		try (Transaction tx = modLibC.getTrace().openTransaction("Map")) {
 			mappings.addModuleMappings(proposal.computeMap().values(), monitor, true);
 		}
@@ -757,16 +758,17 @@ public class TutorialDebuggerScreenShots extends GhidraScreenShotGenerator
 	@Test
 	public void testMemoryMap_CopyNcursesInto() throws Throwable {
 		launchProgramInGdb();
+		long snap = flatDbg.getCurrentSnap();
 		TraceModule modNcurses = flatDbg.getCurrentTrace()
 				.getModuleManager()
 				.getAllModules()
 				.stream()
-				.filter(m -> m.getName().contains("ncurses"))
+				.filter(m -> m.getName(snap).contains("ncurses"))
 				.findAny()
 				.get();
 		DebuggerListingService listings = tool.getService(DebuggerListingService.class);
-		runSwing(() -> listings
-				.setCurrentSelection(new ProgramSelection(new AddressSet(modNcurses.getRange()))));
+		runSwing(() -> listings.setCurrentSelection(
+			new ProgramSelection(new AddressSet(modNcurses.getRange(snap)))));
 		DebuggerListingProvider listingProvider =
 			waitForComponentProvider(DebuggerListingProvider.class);
 		performAction("Copy Into New Program",
